ApiService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
String phoneNumber, String token) → Future< Map< String, dynamic> > - Authenticate user with encrypted phone number
-
checkStatus(
String txnId, String accessToken) → Future< Map< String, dynamic> > -
getAccessToken(
{required String username, required String password}) → Future< Map< String, dynamic> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyOtp(
String txnId, String otp, String accessToken) → Future< Map< String, dynamic> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- baseTokenUrl ↔ String
-
getter/setter pair
- baseUrl ↔ String
-
getter/setter pair
Static Methods
-
initialize(
{required String environment}) → Future< void> - Load environment variables when SDK initializes